@@ -1,8 +1,18 @@
-import pyfstat
-import numpy as np
+"""
+MCMC search: Semicoherent F-statistic with initialisation
+=========================================================
+
+Directed MCMC search for an isolated CW signal using the
+fully-coherent F-statistic. Prior to the burn-in stage, walkers
+are initialized with a certain scattering factor.
+"""
 import os
 
-label = os.path.splitext(os.path.basename(__file__))[0]
+import numpy as np
+
+import pyfstat
+
+label = "PyFstat_example_MCMC_search_using_initialisation"
 outdir = os.path.join("PyFstat_example_data", label)
 
 # Properties of the GW data
