@@ -6,18 +6,20 @@ and are of interest mostly only for developers,
 but others can also be helpful for end users.
 """
 
-import os
-import sys
-import subprocess
 import argparse
-import logging
 import inspect
-import peakutils
+import logging
+import os
 import shutil
+import subprocess
+import sys
 from functools import wraps
-import numpy as np
+
 import lal
 import lalpulsar
+import numpy as np
+import peakutils
+
 from ._version import get_versions
 
 # workaround for matplotlib on X-less remote logins
@@ -140,18 +142,15 @@ def get_ephemeris_files():
     ```
 
     If such a file is not found or does not conform to that format,
-    then the `$LALPULSAR_DATADIR` environment variable is checked
-    for the default `[earth/sun]00-40-DE405` ephemerides.
-    NOTE that this solution is deprecated
-    and will no longer be supported in future versions!
-
-    If that also fails,
-    a warning is emitted.
-    However, the user can still continue,
-    by either relying on lal's recently improved ability to find proper
+    then we rely on lal's recently improved ability to find proper
     default fallback paths for the `[earth/sun]00-40-DE405` ephemerides
     with both pip- and conda-installed packages,
-    or by setting the ephemeris options manually on each class instantiation.
+
+    Alternatively, ephemeris options can be set manually
+    on each class instantiation.
+
+    NOTE that the `$LALPULSAR_DATADIR` environment variable
+    is no longer supported!
 
     Returns
     ----------
@@ -159,7 +158,6 @@ def get_ephemeris_files():
         Paths of the two files containing positions of Earth and Sun.
     """
     config_file = os.path.join(os.path.expanduser("~"), ".pyfstat.conf")
-    env_var = "LALPULSAR_DATADIR"
     ephem_version = "DE405"
     earth_ephem = f"earth00-40-{ephem_version}.dat.gz"
     sun_ephem = f"sun00-40-{ephem_version}.dat.gz"
@@ -180,27 +178,8 @@ def get_ephemeris_files():
             sun_ephem = d["sun_ephem"]
         except KeyError:
             logging.warning(f"No [earth/sun]_ephem found in {config_file}. {please}")
-    elif env_var in list(os.environ.keys()):
-        earth_ephem = os.path.join(os.environ[env_var], earth_ephem)
-        sun_ephem = os.path.join(os.environ[env_var], sun_ephem)
-        if os.path.isfile(earth_ephem) and os.path.isfile(sun_ephem):
-            logging.warning(
-                f"Relying on ${env_var} for ephemerides is deprecated"
-                " and will no longer be supported in future versions!"
-                " You can instead rely on lal's automatic path resolution,"
-                " use a '.pyfstat.conf' file,"
-                " or provide 'earth_ephem' and 'sun_ephem' class options."
-            )
-        else:
-            logging.warning(
-                f"Default ephemerides [{earth_ephem},{sun_ephem}]"
-                f" not found in the {os.environ[env_var]} directory. {please}"
-            )
     else:
-        logging.warning(
-            f"No {config_file} file or ${env_var} environment"
-            f" variable found. {please}"
-        )
+        logging.info(f"No {config_file} file found. {please}")
     return earth_ephem, sun_ephem
 
 
@@ -429,6 +408,81 @@ def convert_array_to_gsl_matrix(array):
     return gsl_matrix
 
 
+def get_sft_as_arrays(sftfilepattern, fMin=None, fMax=None, constraints=None):
+    """
+
+    Parameters
+    ----------
+    sftfilepattern: str
+            Pattern to match SFTs using wildcards (`*?`) and ranges [0-9];
+            multiple patterns can be given separated by colons.
+    fMin, fMax: float or None
+        Restrict frequency range to `[fMin, fMax]`.
+        If None, retreive the full frequency range.
+    constraints: lalpulsar.SFTConstraints() or None
+        Constrains to be fed into XLALSFTdataFind to specify detector,
+        GPS time range or timestamps to be retrieved.
+
+    Returns
+    ----------
+    freqs: np.ndarray
+        The frequency bins in each SFT.
+        These will be the same for each SFT,
+        so only a single 1D array is returned.
+    times: dict of np.ndarray
+        The SFT start times as a dictionary of 1D arrays, one for each detector.
+        Keys correspond to the official detector names as returned by XLALlalpulsar.ListIFOsInCatalog.
+    data: dict of np.ndarray
+        A dictionary of 2D arrays of the complex Fourier amplitudes of the SFT data
+        for each detector in each frequency bin at each timestamp.
+        Keys correspond to the official detector names as returned by XLALlalpulsar.ListIFOsInCatalog.
+    """
+
+    constraints = constraints or lalpulsar.SFTConstraints()
+    if fMin is None and fMax is None:
+        fMin = fMax = -1
+    elif fMin is None or fMax is None:
+        raise ValueError("Need either none or both of fMin, fMax.")
+
+    sft_catalog = lalpulsar.SFTdataFind(sftfilepattern, constraints)
+    ifo_labels = lalpulsar.ListIFOsInCatalog(sft_catalog)
+
+    logging.info(
+        f"Loading {sft_catalog.length} SFTs from {', '.join(ifo_labels.data)}..."
+    )
+    multi_sfts = lalpulsar.LoadMultiSFTs(sft_catalog, fMin, fMax)
+    logging.info("done!")
+
+    times = {}
+    amplitudes = {}
+
+    old_frequencies = None
+    for ind, ifo in enumerate(ifo_labels.data):
+
+        sfts = multi_sfts.data[ind]
+
+        times[ifo] = np.array([sft.epoch.gpsSeconds for sft in sfts.data])
+        amplitudes[ifo] = np.array([sft.data.data for sft in sfts.data]).T
+
+        nbins, nsfts = amplitudes[ifo].shape
+
+        logging.info(f"{nsfts} retrieved from {ifo}.")
+
+        f0 = sfts.data[0].f0
+        df = sfts.data[0].deltaF
+        frequencies = np.linspace(f0, f0 + (nbins - 1) * df, nbins)
+
+        if (old_frequencies is not None) and not np.allclose(
+            frequencies, old_frequencies
+        ):
+            raise ValueError(
+                f"Frequencies don't match between {ifo_labels.data[ind-1]} and {ifo}"
+            )
+        old_frequencies = frequencies
+
+    return frequencies, times, amplitudes
+
+
 def get_sft_array(sftfilepattern, F0=None, dF0=None):
     """Return the raw data (absolute values) from a set of SFTs.
 
@@ -454,6 +508,13 @@ def get_sft_array(sftfilepattern, F0=None, dF0=None):
         A 2D array of the absolute values of the SFT data
         in each frequency bin at each timestamp.
     """
+    if True:  # pragma: no cover
+        import warnings
+
+        warnings.warn(
+            "`get_sft_array` is deprecated and will be removed in a future release. "
+            "Please, use `get_sft_as_arrays` to load SFT complex amplitudes."
+        )
 
     if F0 is None and dF0 is None:
         fMin = -1
